@@ -55,7 +55,17 @@ function selectAllButton(form, item)
   // return the code to display a Select All button that works with form item named item.
   var output = '';
 
-  output += '<input type="button" name="selectAll' + item + '" value="Select All" onClick="selectAll(document.' + form + '.' + item + ');">';
+  output += '<input type="button" name="selectAll' + item + '" value="[*]" title="Select All" onClick="selectAll(document.' + form + '.' + item + ');">';
+
+  return output;
+}
+
+function unSelectAllButton(form, item)
+{
+  // return the code to display a UnSelect All button that works with form item named item.
+  var output = '';
+
+  output += '<input type="button" name="unSelectAll' + item + '" value="[ ]" title="Un-Select All" onClick="unSelectAll(document.' + form + '.' + item + ');">';
 
   return output;
 }
@@ -65,7 +75,7 @@ function toggleSelectButton(form, item)
   // return the code to display a Toggle button that works with form item named item.
   var output = '';
 
-  output += '<input type="button" name="toggleSelect' + item + '" value="Toggle" onClick="toggleSelection(document.' + form + '.' + item + ');">';
+  output += '<input type="button" name="toggleSelect' + item + '" value="><" title="Toggle" onClick="toggleSelection(document.' + form + '.' + item + ');">';
 
   return output;
 }
@@ -104,6 +114,12 @@ function calcDatePrev(field)
 
   // now output the date (year, month, day) and update the field.
   field.value = formatDateNumber(date.getFullYear()) + "-" + formatDateNumber(date.getMonth() + 1) + "-" + formatDateNumber(date.getDate());
+
+  // make sure the onchange handler fires.
+  if (typeof(field.onchange) != "undefined")
+  {
+    field.onchange();
+  }
 }
 
 function calcDateNext(field)
@@ -130,6 +146,12 @@ function calcDateNext(field)
 
   // now output the date (year, month, day) and update the field.
   field.value = formatDateNumber(date.getFullYear()) + "-" + formatDateNumber(date.getMonth() + 1) + "-" + formatDateNumber(date.getDate());
+
+  // make sure the onchange handler fires.
+  if (typeof(field.onchange) != "undefined")
+  {
+    field.onchange();
+  }
 }
 
 // returns a boolean value to say if the html form item contains a valid color.
@@ -156,7 +178,7 @@ function isValidISODate(widget, seperator)
     alert("isValidISODate: seperator='" + seperator + "' is invalid!");
     return false;
   }
-  var dateMask = new RegExp("^(\d{4}" + seperatorReg + "\d{2}" + seperatorReg + "\d{2})$");
+  var dateMask = new RegExp("^(\\d{4}" + seperatorReg + "\\d{2}" + seperatorReg + "\\d{2})$");
   var result = widget.value.match(dateMask);
   if (result == null)
   {
@@ -973,3 +995,14 @@ function htmlForm_updateEntries(a, u, aS, uS, sep)
   u.value = unassigned;
   a.value = assigned;
 }
+
+// array manipulation methods, ala perl style
+
+// qw - returns an array built up from space seperated items in a string.
+// Ex:  var numbers = qw("one two three four five six seven eight nine ten");
+// Make sure you do not have more than 1 space between tokens, otherwise
+// you will get an entry that consists of a space.
+function qw(string)
+{
+  return string.split(' ');
+}
